@@ -44,11 +44,3 @@ class Adapter:
         This is part of the Auto-Save feature.
         """
         pass
-
-    def is_filtered(self):
-        """Marks if the loaded policy is filtered or not"""
-        pass
-
-    def load_filtered_policy(self, model, filter):
-        """Loads policy rules that match the filter from the storage."""
-        pass
